/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.finance.vo.OrderGoodsVO;
import org.springblade.modules.finance.service.IOrderGoodsService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 订单商品表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/ordergoods")
@Api(value = "订单商品表", tags = "订单商品表接口")
public class OrderGoodsController extends BladeController {

	private final IOrderGoodsService orderGoodsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderGoods")
	public R<OrderGoods> detail(OrderGoods orderGoods) {
		OrderGoods detail = orderGoodsService.getOne(Condition.getQueryWrapper(orderGoods));
		return R.data(detail);
	}

	/**
	 * 分页 订单商品表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderGoods")
	public R<IPage<OrderGoods>> list(OrderGoods orderGoods, Query query) {
		IPage<OrderGoods> pages = orderGoodsService.page(Condition.getPage(query), Condition.getQueryWrapper(orderGoods));
		return R.data(pages);
	}

	/**
	 * 自定义分页 订单商品表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderGoods")
	public R<IPage<OrderGoodsVO>> page(OrderGoodsVO orderGoods, Query query) {
		IPage<OrderGoodsVO> pages = orderGoodsService.selectOrderGoodsPage(Condition.getPage(query), orderGoods);
		return R.data(pages);
	}

	/**
	 * 新增 订单商品表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderGoods")
	public R save(@Valid @RequestBody OrderGoods orderGoods) {
		return R.status(orderGoodsService.save(orderGoods));
	}

	/**
	 * 修改 订单商品表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderGoods")
	public R update(@Valid @RequestBody OrderGoods orderGoods) {
		return R.status(orderGoodsService.updateById(orderGoods));
	}

	/**
	 * 新增或修改 订单商品表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderGoods")
	public R submit(@Valid @RequestBody OrderGoods orderGoods) {
		return R.status(orderGoodsService.saveOrUpdate(orderGoods));
	}

	
	/**
	 * 删除 订单商品表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderGoodsService.removeByIds(Func.toLongList(ids)));
	}

	
}
