/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.Brands;
import org.springblade.modules.shopping.vo.BrandsVO;
import org.springblade.modules.shopping.service.IBrandsService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.List;

/**
 * 品牌表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/brands")
@Api(value = "品牌表", tags = "品牌表接口")
public class BrandsController extends BladeController {

	private final IBrandsService brandsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入brands")
	public R<Brands> detail(Brands brands) {
		Brands detail = brandsService.getOne(Condition.getQueryWrapper(brands));
		return R.data(detail);
	}

	/**
	 * 分页 品牌表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入brands")
	public R<IPage<Brands>> list(Brands brands, Query query) {
		IPage<Brands> pages = brandsService.page(Condition.getPage(query), Condition.getQueryWrapper(brands));
		return R.data(pages);
	}

	@GetMapping("/selectList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入brands")
	public R<List<Brands>> selectList(Brands brands) {
		List<Brands> pages = brandsService.list(Condition.getQueryWrapper(brands));
		return R.data(pages);
	}

	/**
	 * 自定义分页 品牌表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入brands")
	public R<IPage<BrandsVO>> page(BrandsVO brands, Query query) {
		IPage<BrandsVO> pages = brandsService.selectBrandsPage(Condition.getPage(query), brands);
		return R.data(pages);
	}

	/**
	 * 新增 品牌表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入brands")
	public R save(@Valid @RequestBody Brands brands) {
		return R.status(brandsService.save(brands));
	}

	/**
	 * 修改 品牌表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入brands")
	public R update(@Valid @RequestBody Brands brands) {
		return R.status(brandsService.updateById(brands));
	}

	/**
	 * 新增或修改 品牌表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入brands")
	public R submit(@Valid @RequestBody Brands brands) {
		return R.status(brandsService.saveOrUpdate(brands));
	}


	/**
	 * 删除 品牌表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(brandsService.removeByIds(Func.toLongList(ids)));
	}


}
