/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 规格分类表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_spec_cats")
@ApiModel(value = "SpecCats对象", description = "规格分类表")
public class SpecCats implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 主键ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "spec_cat_id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long specCatId;
	/**
	 * 分类ID
	 */
	@ApiModelProperty(value = "分类ID")
	private Long catId;
	/**
	 * 分类名
	 */
	@ApiModelProperty(value = "分类名")
	private String catName;

	/**
	 * 规格名称
	 */
	@ApiModelProperty(value = "规格名称")
	private String specName;

	/**
	 * 是否允许上传图片
	 */
	@ApiModelProperty(value = "是否允许上传图片")
	private Integer isAllowImg;

	/**
	 * 是否显示
	 */
	@ApiModelProperty(value = "是否显示")
	private Integer isShow;
	/**
	 * 排序
	 */
	@ApiModelProperty(value = "排序")
	private Integer sort;

	/**
	 *  创建时间
	 */
	private Date createTime;
	/**
	 * 删除标识   0正常  1逻辑删除
	 */
	@TableLogic
	@ApiModelProperty(value = "删除标识   0正常  1逻辑删除")
	private Integer isDeleted;

	/**
	 * 忽略字段
	 */
	@TableField(exist = false)
	private List<SpecItems> specItems;

}
